@@ -1,7 +1,7 @@
 import sys
 import os
 from ec2ools import aws
-from ec2tools.aws import MetaService
+from ec2ools.aws import MetaService
 
 
 class EipBase:
@@ -10,7 +10,7 @@ class EipBase:
         """
         """
         meta = MetaService()
-        instance_id = meta.query('instance-id')
+        instance_id = meta.query_meta('instance-id')
         eip_info = self._query_eip(alloc_id)
 
         if not eip_info:
